@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,23 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
-from google.iam.v1 import policy_pb2 as policy  # type: ignore
-from google.protobuf import struct_pb2 as struct  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
+from google.iam.v1 import policy_pb2  # type: ignore
+from google.protobuf import struct_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
     package="google.cloud.asset.v1p2beta1",
-    manifest={
-        "TemporalAsset",
-        "TimeWindow",
-        "Asset",
-        "Resource",
-    },
+    manifest={"TemporalAsset", "TimeWindow", "Asset", "Resource",},
 )
 
 
@@ -40,52 +32,32 @@ class TemporalAsset(proto.Message):
     it.
 
     Attributes:
-        window (~.assets.TimeWindow):
+        window (google.cloud.asset_v1p2beta1.types.TimeWindow):
             The time window when the asset data and state
             was observed.
         deleted (bool):
             If the asset is deleted or not.
-        asset (~.assets.Asset):
+        asset (google.cloud.asset_v1p2beta1.types.Asset):
             Asset.
     """
 
-    window = proto.Field(
-        proto.MESSAGE,
-        number=1,
-        message="TimeWindow",
-    )
-
-    deleted = proto.Field(proto.BOOL, number=2)
-
-    asset = proto.Field(
-        proto.MESSAGE,
-        number=3,
-        message="Asset",
-    )
+    window = proto.Field(proto.MESSAGE, number=1, message="TimeWindow",)
+    deleted = proto.Field(proto.BOOL, number=2,)
+    asset = proto.Field(proto.MESSAGE, number=3, message="Asset",)
 
 
 class TimeWindow(proto.Message):
     r"""A time window of (start_time, end_time].
-
     Attributes:
-        start_time (~.timestamp.Timestamp):
+        start_time (google.protobuf.timestamp_pb2.Timestamp):
             Start time of the time window (exclusive).
-        end_time (~.timestamp.Timestamp):
+        end_time (google.protobuf.timestamp_pb2.Timestamp):
             End time of the time window (inclusive).
             Current timestamp if not specified.
     """
 
-    start_time = proto.Field(
-        proto.MESSAGE,
-        number=1,
-        message=timestamp.Timestamp,
-    )
-
-    end_time = proto.Field(
-        proto.MESSAGE,
-        number=2,
-        message=timestamp.Timestamp,
-    )
+    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
+    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
 
 
 class Asset(proto.Message):
@@ -102,9 +74,9 @@ class Asset(proto.Message):
         asset_type (str):
             Type of the asset. Example:
             "compute.googleapis.com/Disk".
-        resource (~.assets.Resource):
+        resource (google.cloud.asset_v1p2beta1.types.Resource):
             Representation of the resource.
-        iam_policy (~.policy.Policy):
+        iam_policy (google.iam.v1.policy_pb2.Policy):
             Representation of the actual Cloud IAM policy
             set on a cloud resource. For each resource,
             there must be at most one Cloud IAM policy set
@@ -120,28 +92,15 @@ class Asset(proto.Message):
             "organizations/1234"]
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    asset_type = proto.Field(proto.STRING, number=2)
-
-    resource = proto.Field(
-        proto.MESSAGE,
-        number=3,
-        message="Resource",
-    )
-
-    iam_policy = proto.Field(
-        proto.MESSAGE,
-        number=4,
-        message=policy.Policy,
-    )
-
-    ancestors = proto.RepeatedField(proto.STRING, number=6)
+    name = proto.Field(proto.STRING, number=1,)
+    asset_type = proto.Field(proto.STRING, number=2,)
+    resource = proto.Field(proto.MESSAGE, number=3, message="Resource",)
+    iam_policy = proto.Field(proto.MESSAGE, number=4, message=policy_pb2.Policy,)
+    ancestors = proto.RepeatedField(proto.STRING, number=6,)
 
 
 class Resource(proto.Message):
     r"""Representation of a cloud resource.
-
     Attributes:
         version (str):
             The API version. Example: "v1".
@@ -176,27 +135,18 @@ class Resource(proto.Message):
             ``"//cloudresourcemanager.googleapis.com/projects/my_project_123"``.
 
             For third-party assets, it is up to the users to define.
-        data (~.struct.Struct):
+        data (google.protobuf.struct_pb2.Struct):
             The content of the resource, in which some
             sensitive fields are scrubbed away and may not
             be present.
     """
 
-    version = proto.Field(proto.STRING, number=1)
-
-    discovery_document_uri = proto.Field(proto.STRING, number=2)
-
-    discovery_name = proto.Field(proto.STRING, number=3)
-
-    resource_url = proto.Field(proto.STRING, number=4)
-
-    parent = proto.Field(proto.STRING, number=5)
-
-    data = proto.Field(
-        proto.MESSAGE,
-        number=6,
-        message=struct.Struct,
-    )
+    version = proto.Field(proto.STRING, number=1,)
+    discovery_document_uri = proto.Field(proto.STRING, number=2,)
+    discovery_name = proto.Field(proto.STRING, number=3,)
+    resource_url = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(proto.STRING, number=5,)
+    data = proto.Field(proto.MESSAGE, number=6, message=struct_pb2.Struct,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
